cpglm function to fit the compound Poisson generalized linear model. Several primitive methods and statistical methods are created to facilitate the extraction of specific slots and further statistical analysis.new("cpglm", ...), or they could also be a result of calls from cpglm."list ", from data part.
Class "vector ", by class "list", distance 2.
Class "NullList ", by class "list", distance 2.cpglm, glm and glm.summaries.